<?php
// recent-reviews.php - Displays recent reviews in the database

// Set error handling
ini_set('display_errors', 0);
error_reporting(E_ALL);

// Function to handle errors as JSON
function returnError($message, $statusCode = 500) {
    http_response_code($statusCode);
    header("Content-Type: application/json");
    echo json_encode(['error' => $message]);
    exit;
}

// Set headers
header("Content-Type: application/json");
header("Access-Control-Allow-Origin: *");
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");

// Use a try-catch for all code
try {
    // Connect to SQLite database
    $dbPath = '/home/phantomales/TastingTrail/Producer.db';
    
    // Check if database file exists
    if (!file_exists($dbPath)) {
        returnError("Database file not found at: $dbPath");
    }
    
    // Connect to the database
    $db = new SQLite3($dbPath);
    
    if (!$db) {
        returnError("Failed to open database: " . SQLite3::lastErrorMsg());
    }
    
    // Query to get recent reviews
    $sql = "
        SELECT 
            r.ReviewID, 
            r.ProducerID, 
            r.Rating, 
            r.ReviewText,
            r.CreatedAt,
            p.CompanyName,
            p.DBA
        FROM ProducerReviews r
        JOIN ProducerList_Prod p ON r.ProducerID = p.ProducerID
        ORDER BY r.CreatedAt DESC
        LIMIT 10
    ";
    
    $result = $db->query($sql);
    if (!$result) {
        returnError("Failed to execute review query: " . $db->lastErrorMsg());
    }
    
    // Fetch review results
    $reviews = [];
    while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
        // Query to get product reviews for this review
        $productSql = "
            SELECT 
                pr.ProductID,
                pr.Rating,
                pr.QuickTake,
                p.Name,
                p.Category,
                p.Style
            FROM ProductReviews pr
            JOIN Products p ON pr.ProductID = p.ProductID
            WHERE pr.ReviewID = :reviewId
        ";
        
        $productStmt = $db->prepare($productSql);
        $productStmt->bindValue(':reviewId', $row['ReviewID'], SQLITE3_INTEGER);
        $productResult = $productStmt->execute();
        
        $products = [];
        while ($productRow = $productResult->fetchArray(SQLITE3_ASSOC)) {
            $products[] = $productRow;
        }
        
        $row['Products'] = $products;
        $row['ProductCount'] = count($products);
        
        $reviews[] = $row;
    }
    
    // Return JSON response
    echo json_encode([
        'reviews' => $reviews,
        'count' => count($reviews),
        'timestamp' => date('Y-m-d H:i:s')
    ], JSON_NUMERIC_CHECK);
    
    // Close database connection
    $db->close();
    
} catch (Exception $e) {
    returnError("Caught exception: " . $e->getMessage());
} catch (Error $e) {
    returnError("Caught error: " . $e->getMessage());
}
?>